@@ -4,7 +4,7 @@ from deficrawler.lending import Lending
 def test_borrow_aave_2_eth():
     aave = Lending(protocol="Aave", chain="Ethereum", version=2)
     borrows = aave.get_data_from_date_range(
-        '11/05/2021 00:00:01', '11/05/2021 00:01:00', "borrow")
+        '11/05/2021 00:00:01', '11/05/2021 01:01:00', "borrow")
 
     assert(borrows[0]['tx_id'] != "")
     assert(borrows[0]['protocol'] == "Aave")
@@ -40,6 +40,21 @@ def test_borrow_aave_2_polygon():
     assert(borrows[0]['timestamp'] > 0)
 
 
+def test_borrow_aave_2_avalanche():
+    aave = Lending(protocol="Aave", chain="avalanche", version=2)
+    borrows = aave.get_data_from_date_range(
+        '16/10/2021 00:00:01', '18/10/2021 00:01:10', "borrow")
+
+    assert(borrows[0]['tx_id'] != "")
+    assert(borrows[0]['protocol'] == "Aave")
+    assert(borrows[0]['chain'] == "avalanche")
+    assert(borrows[0]['version'] == 2)
+    assert(borrows[0]['user'] != "")
+    assert(borrows[0]['token'] != "")
+    assert(borrows[0]['amount'] > 0)
+    assert(borrows[0]['timestamp'] > 0)
+
+
 def test_borrow_aave_2_polygon_user():
     aave = Lending(protocol="Aave", chain="Polygon", version=2)
     borrows = aave.get_data_from_date_range(
@@ -52,7 +67,7 @@ def test_borrow_aave_2_polygon_user():
 def test_borrow_compound_2_eth():
     compound = Lending(protocol="Compound", chain="Ethereum", version=2)
     borrows = compound.get_data_from_date_range(
-        '11/05/2021 00:00:01', '11/05/2021 00:01:10', "borrow")
+        '11/10/2020 00:00:01', '11/11/2020 1:01:10', "borrow")
 
     assert(borrows[0]['tx_id'] != "")
     assert(borrows[0]['protocol'] == "Compound")
@@ -117,6 +132,36 @@ def test_borrow_cream_2_arbitrum():
     assert(borrows[0]['timestamp'] > 0)
 
 
+def test_borrow_cream_2_fantom():
+    cream = Lending(protocol="Cream", chain="fantom", version=2)
+    borrows = cream.get_data_from_date_range(
+        '20/10/2021 00:00:01', '21/10/2021 00:00:00', "borrow")
+
+    assert(borrows[0]['tx_id'] != "")
+    assert(borrows[0]['protocol'] == "Cream")
+    assert(borrows[0]['chain'] == "fantom")
+    assert(borrows[0]['version'] == 2)
+    assert(borrows[0]['user'] != "")
+    assert(borrows[0]['token'] != "")
+    assert(float(borrows[0]['amount']) > 0)
+    assert(borrows[0]['timestamp'] > 0)
+
+
+def test_borrow_cream_2_avalanche():
+    cream = Lending(protocol="Cream", chain="avalanche", version=2)
+    borrows = cream.get_data_from_date_range(
+        '20/10/2021 00:00:01', '21/10/2021 00:00:00', "borrow")
+
+    assert(borrows[0]['tx_id'] != "")
+    assert(borrows[0]['protocol'] == "Cream")
+    assert(borrows[0]['chain'] == "avalanche")
+    assert(borrows[0]['version'] == 2)
+    assert(borrows[0]['user'] != "")
+    assert(borrows[0]['token'] != "")
+    assert(float(borrows[0]['amount']) > 0)
+    assert(borrows[0]['timestamp'] > 0)
+
+
 def test_borrow_cream_2_eth_user():
     cream = Lending(protocol="Cream", chain="Ethereum", version=2)
     borrows = cream.get_data_from_date_range(
@@ -175,16 +220,16 @@ def test_borrow_kashi_1_eth_user():
         assert(borrow['user'] == "0xb715606b0482bd0ec5c54e8dc616e1deb59d5308")
 
 
-def test_borrow_kashi_1_polygon():
-    kashi = Lending(protocol="Kashi", chain="Polygon", version=1)
-    borrows = kashi.get_data_from_date_range(
-        '30/09/2021 00:00:01', '30/09/2021 11:54:10', "borrow")
+# def test_borrow_kashi_1_polygon():
+#     kashi = Lending(protocol="Kashi", chain="Polygon", version=1)
+#     borrows = kashi.get_data_from_date_range(
+#         '30/03/2023 00:00:01', '30/03/2022 11:54:10', "borrow")
 
-    assert(borrows[0]['tx_id'] != "")
-    assert(borrows[0]['protocol'] == "Kashi")
-    assert(borrows[0]['chain'] == "Polygon")
-    assert(borrows[0]['version'] == 1)
-    assert(borrows[0]['user'] != "")
-    assert(borrows[0]['token'] != "")
-    assert(float(borrows[0]['amount']) > 0)
-    assert(borrows[0]['timestamp'] > 0)
+#     assert(borrows[0]['tx_id'] != "")
+#     assert(borrows[0]['protocol'] == "Kashi")
+#     assert(borrows[0]['chain'] == "Polygon")
+#     assert(borrows[0]['version'] == 1)
+#     assert(borrows[0]['user'] != "")
+#     assert(borrows[0]['token'] != "")
+#     assert(float(borrows[0]['amount']) > 0)
+#     assert(borrows[0]['timestamp'] > 0)
