@@ -39,6 +39,21 @@ def test_deposit_aave_2_polygon():
     assert(deposits[0]['timestamp'] > 0)
 
 
+def test_deposit_aave_2_avalanche():
+    aave = Lending(protocol="Aave", chain="Avalanche", version=2)
+    deposits = aave.get_data_from_date_range(
+        '16/10/2021 00:00:01', '16/10/2021 09:01:10', "deposit")
+
+    assert(deposits[0]['tx_id'] != "")
+    assert(deposits[0]['protocol'] == "Aave")
+    assert(deposits[0]['chain'] == "Avalanche")
+    assert(deposits[0]['version'] == 2)
+    assert(deposits[0]['user'] != "")
+    assert(deposits[0]['token'] != "")
+    assert(deposits[0]['amount'] > 0)
+    assert(deposits[0]['timestamp'] > 0)
+
+
 def test_deposit_aave_2_polygon_user():
     aave = Lending(protocol="Aave", chain="Polygon", version=2)
     deposits = aave.get_data_from_date_range(
@@ -51,7 +66,7 @@ def test_deposit_aave_2_polygon_user():
 def test_deposit_compound_2_eth():
     compound = Lending(protocol="Compound", chain="Ethereum", version=2)
     deposits = compound.get_data_from_date_range(
-        '11/05/2021 00:00:01', '11/05/2021 00:01:10', "deposit")
+        '11/05/2021 00:00:01', '11/05/2021 01:01:10', "deposit")
 
     assert(deposits[0]['tx_id'] != "")
     assert(deposits[0]['protocol'] == "Compound")
@@ -126,6 +141,35 @@ def test_deposit_cream_2_bsc():
     assert(deposits[0]['timestamp'] > 0)
 
 
+def test_deposit_cream_2_fantom():
+    cream = Lending(protocol="Cream", chain="fantom", version=2)
+    deposits = cream.get_data_from_date_range(
+        '10/10/2021 00:00:01', '19/10/2021 00:00:00', "deposit")
+
+    assert(deposits[0]['tx_id'] != "")
+    assert(deposits[0]['protocol'] == "Cream")
+    assert(deposits[0]['chain'] == "fantom")
+    assert(deposits[0]['version'] == 2)
+    assert(deposits[0]['user'] != "")
+    assert(deposits[0]['token'] != "")
+    assert(float(deposits[0]['amount']) > 0)
+    assert(deposits[0]['timestamp'] > 0)
+
+
+def test_deposit_cream_2_avalanche():
+    cream = Lending(protocol="Cream", chain="avalanche", version=2)
+    deposits = cream.get_data_from_date_range(
+        '10/10/2021 00:00:01', '19/10/2021 00:00:00', "deposit")
+
+    assert(deposits[0]['tx_id'] != "")
+    assert(deposits[0]['protocol'] == "Cream")
+    assert(deposits[0]['chain'] == "avalanche")
+    assert(deposits[0]['version'] == 2)
+    assert(deposits[0]['user'] != "")
+    assert(deposits[0]['token'] != "")
+    assert(float(deposits[0]['amount']) > 0)
+    assert(deposits[0]['timestamp'] > 0)
+
 def test_deposit_cream_2_bsc_user():
     cream = Lending(protocol="Cream", chain="bsc", version=2)
     deposits = cream.get_data_from_date_range(
@@ -150,16 +194,3 @@ def test_deposit_kashi_1_eth():
     assert(deposits[0]['timestamp'] > 0)
 
 
-def test_deposit_kashi_1_polygon():
-    kashi = Lending(protocol="kashi", chain="Polygon", version=1)
-    deposits = kashi.get_data_from_date_range(
-        '25/09/2021 00:00:01', '30/09/2021 11:54:10', "deposit")
-
-    assert(deposits[0]['tx_id'] != "")
-    assert(deposits[0]['protocol'] == "kashi")
-    assert(deposits[0]['chain'] == "Polygon")
-    assert(deposits[0]['version'] == 1)
-    assert(deposits[0]['user'] != "")
-    assert(deposits[0]['token'] != "")
-    assert(float(deposits[0]['amount']) > 0)
-    assert(deposits[0]['timestamp'] > 0)
