@@ -4,7 +4,7 @@ from deficrawler.lending import Lending
 def test_repay_aave_2_eth():
     aave = Lending(protocol="Aave", chain="Ethereum", version=2)
     repays = aave.get_data_from_date_range(
-        '11/05/2021 00:00:01', '11/05/2021 00:01:00', "repay")
+        '11/05/2021 00:00:01', '11/05/2021 00:31:00', "repay")
     assert(repays[0]['tx_id'] != "")
     assert(repays[0]['protocol'] == "Aave")
     assert(repays[0]['chain'] == "Ethereum")
@@ -38,6 +38,22 @@ def test_repay_aave_2_polygon():
     assert(repays[0]['amount'] > 0)
     assert(repays[0]['timestamp'] > 0)
 
+
+def test_repay_aave_2_avalanche():
+    aave = Lending(protocol="Aave", chain="Avalanche", version=2)
+    repays = aave.get_data_from_date_range(
+        '17/10/2021 00:00:01', '18/10/2021 00:01:10', "repay")
+
+    assert(repays[0]['tx_id'] != "")
+    assert(repays[0]['protocol'] == "Aave")
+    assert(repays[0]['chain'] == "Avalanche")
+    assert(repays[0]['version'] == 2)
+    assert(repays[0]['user'] != "")
+    assert(repays[0]['token'] != "")
+    assert(repays[0]['amount'] > 0)
+    assert(repays[0]['timestamp'] > 0)
+
+
 def test_repay_aave_2_polygon_user():
     aave = Lending(protocol="Aave", chain="Polygon", version=2)
     repays = aave.get_data_from_date_range(
@@ -51,7 +67,7 @@ def test_repay_aave_2_polygon_user():
 def test_repay_compound_2_eth():
     compound = Lending(protocol="Compound", chain="Ethereum", version=2)
     repays = compound.get_data_from_date_range(
-        '11/05/2021 00:00:01', '11/05/2021 00:01:10', "repay")
+        '11/05/2021 00:00:01', '11/05/2021 00:31:10', "repay")
 
     assert(repays[0]['tx_id'] != "")
     assert(repays[0]['protocol'] == "Compound")
@@ -138,6 +154,22 @@ def test_repay_cream_2_bsc():
     assert(repays[0]['timestamp'] > 0)
 
 
+
+def test_repay_cream_2_bsc():
+    cream = Lending(protocol="Cream", chain="avalanche", version=2)
+    repays = cream.get_data_from_date_range(
+        '18/10/2021 00:00:01', '19/10/2021 00:00:10', "repay")
+
+    assert(repays[0]['tx_id'] != "")
+    assert(repays[0]['protocol'] == "Cream")
+    assert(repays[0]['chain'] == "avalanche")
+    assert(repays[0]['version'] == 2)
+    assert(repays[0]['user'] != "")
+    assert(repays[0]['token'] != "")
+    assert(float(repays[0]['amount']) > 0)
+    assert(repays[0]['timestamp'] > 0)
+
+
 def test_repay_cream_2_bsc():
     cream = Lending(protocol="Cream", chain="bsc", version=2)
     repays = cream.get_data_from_date_range(
@@ -163,16 +195,3 @@ def test_repay_kashi_1_eth():
     assert(repays[0]['timestamp'] > 0)
 
 
-def test_repay_kashi_1_polygon():
-    kashi = Lending(protocol="Kashi", chain="Polygon", version=1)
-    repays = kashi.get_data_from_date_range(
-        '20/09/2021 00:00:01', '20/09/2021 11:54:10', "repay")
-
-    assert(repays[0]['tx_id'] != "")
-    assert(repays[0]['protocol'] == "Kashi")
-    assert(repays[0]['chain'] == "Polygon")
-    assert(repays[0]['version'] == 1)
-    assert(repays[0]['user'] != "")
-    assert(repays[0]['token'] != "")
-    assert(float(repays[0]['amount']) > 0)
-    assert(repays[0]['timestamp'] > 0)
